@@ -7,8 +7,11 @@
 
 #include "Reports.h"
 #include "Rules.h"
+#include "Exclusions.h"
+#include <sstream>
 #include <map>
 #include <utility>
+#include <stdexcept>
 #include <boost/algorithm/string/replace.hpp>
 
 
@@ -65,7 +68,22 @@ int Reports::count()
 
 void Reports::add(const FileName & name, int lineNumber, const Message & msg)
 {
+    if (lineNumber <= 0)
+    {
+      std::ostringstream ss;
+      ss << "Line number out of range: " << lineNumber;
+      throw std::out_of_range(ss.str());
+    }
     const Rules::RuleName currentRule = Rules::getCurrentRule();
+    if (Exclusions::isExcluded(name, lineNumber, currentRule, msg) == false)
+    {
+        messages_[name].insert(make_pair(lineNumber, make_pair(currentRule, msg)));
+    }
+}
+
+void Reports::internal(const FileName & name, int lineNumber, const Message & msg)
+{
+    const Rules::RuleName currentRule = "vera++ internal";
 
     messages_[name].insert(make_pair(lineNumber, make_pair(currentRule, msg)));
 }
