@@ -12,6 +12,8 @@
 #include <map>
 #include <fstream>
 #include <sstream>
+#include <cstring>
+#include <cerrno>
 
 
 namespace // unnamed
@@ -57,10 +59,16 @@ void SourceLines::loadFile(const SourceFiles::FileName & name)
         if (file.is_open() == false)
         {
             std::ostringstream ss;
-            ss << "cannot open source file " << name;
+            ss << "Cannot open source file " << name << ": "
+               << strerror(errno);
             throw SourceFileError(ss.str());
         }
         SourceLines::loadFile(file, name);
+        if (file.bad())
+        {
+            throw std::runtime_error(
+                "Cannot read from " + name + ": " + strerror(errno));
+        }
     }
 }
 
@@ -78,8 +86,8 @@ void SourceLines::loadFile(std::istream & file, const SourceFiles::FileName & na
         // built-in rule
         if (file.eof())
         {
-            Plugins::Reports::add(name, static_cast<int>(lines.size()),
-                "no newline at end of file");
+            // Plugins::Reports::internal(name, static_cast<int>(lines.size()),
+            //     "no newline at end of file");
         }
         else
         {
