@@ -9,6 +9,34 @@ if (x)
     foo();
 }
 
+if (x)
+{                 // OK
+    foo();
+}
+else
+    foo();        // bad style
+
+if (x)
+{                 // OK
+    foo();
+}
+else
+{
+    foo();        // OK
+}
+
+if (x)
+{                 // OK
+    foo();
+}
+else if (x)
+    foo();        // bad style
+
+if (x) {   // OK
+    foo();
+} else if (x) { foo(); }        // OK
+	
+
 if (x)
     while (y)     // bad style
         foo();    // bad style
@@ -24,6 +52,8 @@ if (x)
 for (int i = 0; i = 10; ++i);  // oops!
     cout << "Hello\n";
 
+#pragma omp parallel for \
+    private(k)
 for (int i = 0; i = 10; ++i)   // OK
 {
     cout << "Hello\n";
